# hex_to_cmyk()

## How to use

```python
from colorcodetools.hex.convert import HexToCmyk
rgb_to_hex = HexToCmyk()
rgb_to_hex.hex_to_cmyk("#f2f2f2")
   ```

## Parameters

1. Required parameters:

   - hexcode:  
      Enter hex code which should be converted.
     - `type: string`
     - `default: None`
     - `example: '#f2f2f2'`

## Return value

- `type: boolean or string`